If you redistribute LASExplanation, please follow the terms established in
[the license](/LICENSE). If you wish to cite LASExplanation in an academic
publication, please use the following reference:

Formatted:
```
K. Peng, R. Agrawal, T. Menzies (2020).
LASExplanation - An explanation tool extended from LIME and SHAP
```

BibTeX:
```bibtex
@misc{Peng2020,
abstract = {LASExplanation is a brief wrap-up toolkit built based on 2 explanation packages: LIME and SHAP. The package contains 2 explainers: LIMEBAG and SHAP. It takes data and fitted models as input and returns explanations about feature importance ranks and/or weights. (etc. what attributes matter most within the prediction model).},
address = {Raleigh},
author = {K. Peng, R. Agrawal, T. Menzies},
publisher = {},
title = {{LASExplanation - An explanation tool extended from LIME and SHAP}},
url = {https://github.com/kpeng2019/LAS},
year = {2020}
}
```
